clear
set more off
set mem 100m
use appended.dta
capture log close
log using sum_statslog.smcl, replace

/*Create a 1 male vs. 1 female dummy; 1 male vs. 1 male; and 1 fem vs. 1 fem*/
gen mvf=0
gen mvm=0
gen fvf=0
sort year state
by year state: egen n_gen_cand=total(gen_cand)
by year state: egen n_femcand=total(female) if gen_cand==1
replace mvf=1 if n_gen_cand==2 & n_femcand==1 & gen_cand==1
replace mvm=1 if n_gen_cand==2 & n_femcand==0 & gen_cand==1
replace fvf=1 if n_gen_cand==2 & n_femcand==2 & gen_cand==1
*foreach i in mvf mvm fvf{
*by year state: egen x`i'=max(`i')
*drop `i'
*rename x`i' `i'
*}
replace n_gen_cand=. if gen_cand==0
gen _2persontype="."
replace _2persontype="mvf" if mvf==1
replace _2persontype="mvm" if mvm==1
replace _2persontype="fvf" if fvf==1
replace _2persontype="_multi" if _2persontype=="." & gen_cand==1
label variable _2persontype "If 2 person general election, this was the gender composition"
order year state candidate female party incumbent_in_general open pubfnc prev_occ primary_vote ///
 primary_vote_r general_vote  gen_cand mvf mvm fvf n_gen_cand  n_femcand _total_spend_real
label variable mvf "Dummy for elections that were in a 2 person, male vs. female general election"
label variable mvm "Dummy for elections that were in a 2 person, male vs. male general election"
label variable fvf "Dummy for elections that were in a 2 person, female vs. female general election"
label variable gen_cand "Dummy for candidates who were in the general election"
label variable n_gen_cand "Number of general election candidates"
label variable n_femcand "Number of female general election candidates"




  /////////////////////////////////////////////////////////////////
 /*Uses appended data to generate summary statistics of data set*/
/////////////////////////////////////////////////////////////////

************************************
*Number of elections and candidates*
************************************

/*1. Count the total number of elections, then by year, and then by state*/
sum marker
table year, contents(count marker)
histogram year if marker==1, bin(33) frequency
table state, contents(count marker)

/*2. Count the number of total and general candidates in my data*/
tab gen_cand
tab gen_cand if party !="3rd/Ind."

/*3. Count the number of total and general candidates in my data, broken down by gender*/
tab gen_cand female, row
tab gen_cand female if party !="3rd/Ind.", row


*****************
*Party breakdown*
*****************

/*4. Tab the party breakdown, then by year, and then by state*/
tab party
tab state party, row
tab year party, row
tab party if gen_cand==1
tab state party if gen_cand==1
tab year party if gen_cand==1

/*6. Tab the party by gender*/
tab party female, row col
tab party female if gen_cand==1, row col


***************
*MvF breakdown*
***************

/*7. 2-candidate vs. multi-candidate elections*/
tab n_gen_cand if won_general==1

/*8. Types of elections: MvF, MvM, FvF, or multi(more than 2)-person elections*/
tab _2persontype if won_general==1
tab _2persontype if won_general==1 & _2persontype != "_multi"

/*9. Shows 2-person elections featuring at least one independent or 3rd party*/
list year state candidate reweight party if gen_cand==1 & _2persontype !="_multi" & third_party==1
/*This demonstrates that there are _no_ 2 person elections that feature a third party.
Put differently, every single 2 person election features 2 candidates from the major
parties.*/

/*10. What's the vote share breakdown for the 15% of elections with more than 2 candidates?*/
sort reweight
tab vsbin if gen_cand==1 & n_gen_cand==3
histogram general_vote if gen_cand==1 & n_gen_cand==3, width(5)
/*Based on the histogram and tabulation, a large chunk (18%) of 3 person 
elections feature candidates that received 10% of the vote or less. Perhaps
we could drop those candidates (as a robustness check later on) and
reclassify them as 2 person elections*/


**********************
*Incumbency breakdown*
**********************

/*12. Tab the incumbency (in GENERAL elections) breakdown, then by year, then by state*/
tab incumbent_in_general
tab incumbent_in_general if gen_cand==1
tab state incumbent_in_general if gen_cand==1, row
tab year incumbent_in_general if gen_cand==1, row

/*14. Compare incumbency in primary to incumbency in general elections*/
tab incumbent incumbent_in_general, row

/*15. How do incumbents do against challengers in non-open elections?*/
table incumbent pubfnc if open==0 & n_gen_cand==2 & gen_cand==1, contents(mean reweight)

/*In these non-open, 2 person elections, the gap between incumbent and challenger
narrows slightly when public finance is in effect. The gap drops from 18 pips
to 16 pips*/


**********************
*Vote share breakdown*
**********************

/*16. Mean vote share for women and party*/
table female if reweight>0, contents(mean reweight sd reweight)
table female if third_party==0 & reweight>0, contents(mean reweight sd reweight)
table female party if reweight>0, contents(mean reweight sd reweight)

/*17. General MVF figures*/
table female if mvf==1, contents(mean reweight sd reweight)
table female party if mvf==1, contents(mean reweight)

/*19. Open elections and incumbency for MVF races*/
table female open if mvf==1, contents(mean reweight sd reweight)
table incumbent if mvf==1, contents(mean reweight sd reweight)
table female incumbent if open==0 & mvf==1, contents(mean reweight sd reweight)
table female party incumbent if open==0 & mvf==1, contents(mean reweight)

/*20. This is like 19, but incorportaing public campaign laws*/
table female pubfnc if mvf==1, contents(mean reweight)
table female pubfnc open if mvf==1, contents(mean reweight)
table female pubfnc incumbent if open==0 & mvf==1, contents(mean reweight)


/*21.*/
tab female incumbent_in, row col



log close
view sum_statslog.smcl

clear
set more off
set mem 100m
use appended.dta
capture log close
log using results.smcl, replace

/*Table of Contents

1. LHS: The percentage of females in a primary; the number of females in a
	  primary.
   RHS: Dummy for an open primary
   Fixed effects?: State

2. LHS: The percentage of females in a primary; the number of females in a
	  primary.
   RHS: Dummy for public campaign finance
   Fixed effects?: State

3. LHS: Raw (unweighted) general vote share for a female
   RHS: Time; time squared
   Fixed effects?: State

4. LHS: Average raw (unweighted) female vote share for a given year
   RHS: Time; time squared
   Fixed effects?: No

5. LHS: Dummy for a female general election candidate
   RHS: Dummy for an open general election; time; dummy for public campaign
	  finance
   Fixed effects?: State

6. LHS: 2-candidate female reweighted vote share
   RHS: Log of female spending; log of male spending; share of female 
	  spending; dummy for female incumbent; dummy for male incumbent;
	  time
   Fixed effects?: State

7. LHS: 2-candidate male reweighted vote share
   RHS: Log of male spending; 
   Fixed effects?: State

8. LHS: 2-candidate female reweighted vote share
   RHS: Time; time squared
   Fixed effects?: State

9. LHS: 2-candidate female reweighted vote share
   RHS: Dummy for public campaign finance; dummy for partial funding; dummy
	  for full funding
   Fixed effects?: State; time; state and time interaction

10. LHS: 2-candidate female reweighted vote share
    RHS: Dummy for an open election; time
    Fixed effects?: State



*/
/*Note: I drop the candidates below with unknown sex. This represents 
about 2.4% of my sample*/
drop if female==-9
drop marker
sort state year
by state year: gen marker=1 if _n==1
label variable marker "=1 if candidate is the first observation for election year"
ssc install estout, replace

/*Create a 1 male vs. 1 female dummy; 1 male vs. 1 male; and 1 fem vs. 1 fem*/
gen mvf=0
gen mvm=0
gen fvf=0
sort year state
by year state: egen n_gen_cand=total(gen_cand)
by year state: egen n_femcand=total(female) if gen_cand==1
replace mvf=1 if n_gen_cand==2 & n_femcand==1 & gen_cand==1
replace mvm=1 if n_gen_cand==2 & n_femcand==0 & gen_cand==1
replace fvf=1 if n_gen_cand==2 & n_femcand==2 & gen_cand==1
*foreach i in mvf mvm fvf{
*by year state: egen x`i'=max(`i')
*drop `i'
*rename x`i' `i'
*}
replace n_gen_cand=. if gen_cand==0
gen _2persontype="."
replace _2persontype="mvf" if mvf==1
replace _2persontype="mvm" if mvm==1
replace _2persontype="fvf" if fvf==1
replace _2persontype="_multi" if _2persontype=="." & gen_cand==1
label variable _2persontype "If 2 person general election, this was the gender composition"
label variable mvf "Dummy for elections that were in a 2 person, male vs. female general election"
label variable mvm "Dummy for elections that were in a 2 person, male vs. male general election"
label variable fvf "Dummy for elections that were in a 2 person, female vs. female general election"
label variable gen_cand "Dummy for candidates who were in the general election"
label variable n_gen_cand "Number of general election candidates"
label variable n_femcand "Number of female general election candidates"

*/*Generate inverse general candidates variable*/
*gen invngc=1/n_gen_cand
*by year state: egen INV_NGC=max(invngc)
*drop invngc

***
*1*
***
reg pct_pri_fem open_pri t democrat if pri_marker==1 & third_party==0
est store a1
areg pct_pri_fem open_pri t democrat if pri_marker==1 & third_party==0, absorb(state)
est store a2
reg n_femcand_pri open_pri t democrat if pri_marker==1 & third_party==0
est store a3
areg n_femcand_pri open_pri t democrat if pri_marker==1 & third_party==0, absorb(state)
est store a4
esttab a* using regression_output/presentation/a.rtf, replace


***
*2*
***

reg pct_pri_fem pubfnc t democrat if pri_marker==1 & third_party==0
est store b3
areg pct_pri_fem pubfnc t democrat if pri_marker==1 & third_party==0, absorb(state)
est store b4
reg n_femcand_pri pubfnc t democrat if pri_marker==1 & third_party==0
est store b1
areg n_femcand_pri pubfnc t democrat if pri_marker==1 & third_party==0, absorb(state)
est store b2
esttab b* using regression_output/presentation/b.rtf, replace

***
*3*
***

reg general_vote_raw t if general_vote_raw>=5 & female==1
est store c1
areg general_vote_raw t if general_vote_raw>=5 & female==1, absorb(state)
est store c2
areg general_vote_raw t gfr gfd if general_vote_raw>=5 & female==1, absorb(state)
est store c3
reg general_vote_raw t tsq if general_vote_raw>=5 & female==1
est store c4
areg general_vote_raw t tsq if general_vote_raw>=5 & female==1, absorb(state)
est store c5
areg general_vote_raw t tsq gfr gfd if general_vote_raw>=5 & female==1, absorb(state)
est store c6
esttab c* using regression_output/presentation/c.rtf, replace
scatter general_vote_raw year if general_vote_raw>=5 & female==1

***
*4*
***

sort year
by year: egen avgfvs=mean(general_vote_raw) if general_vote_raw>=5 & female==1
by year: egen avfvs=max(avgfvs)
by year: gen yr_marker=1 if _n==1
label variable yr_marker "=1 if candidate is first observation in a given year"
drop avgfvs
label variable avfvs "The average (raw) female vote share in general elections for a given year"
reg avfvs t if yr_marker==1
est store d1
reg avfvs t tsq if yr_marker==1
est store d2
esttab d* using regression_output/presentation/d.rtf, replace
scatter avfvs year

***
*5*
***

sort year state
capture drop fig
by year state: gen fig=1 if femgen_vote>=5 & femgen_vote !=.
by year state: egen fem_in_gen=max(fig)
label variable fem_in_gen "=1 if a female appeared in this state year's general election"
drop fig
replace fem_in_gen=0 if fem_in_gen==.
tab fem_in_gen open if won_general==1, missing row col

dprobit fem_in_gen open t if marker==1
est store e1
dprobit fem_in_gen open t sd2-sd50 if marker==1
est store e2
dprobit fem_in_gen pubfnc t if marker==1
est store e3
dprobit fem_in_gen pubfnc t sd2-sd50 if marker==1
est store e4
dprobit fem_in_gen pubfnc open t if marker==1
est store e5
dprobit fem_in_gen pubfnc open t sd2-sd50 if marker==1
est store e6
esttab e* using regression_output/presentation/e.rtf, replace

dprobit gfd open t if marker==1
est store x1
dprobit gfd open t sd2-sd50 if marker==1
est store x2
dprobit gfd pubfnc t if marker==1
est store x3
dprobit gfd pubfnc t sd2-sd50 if marker==1
est store x4
dprobit gfd pubfnc open t if marker==1
est store x5
dprobit gfd pubfnc open t sd2-sd50 if marker==1
est store x6
esttab x* using regression_output/presentation/x.rtf, replace

dprobit gfr open t if marker==1
est store w1
dprobit gfr open t sd2-sd50 if marker==1
est store w2
dprobit gfr pubfnc t if marker==1
est store w3
dprobit gfr pubfnc t sd2-sd50 if marker==1
est store w4
dprobit gfr pubfnc open t if marker==1
est store w5
dprobit gfr pubfnc open t sd2-sd50 if marker==1
est store w6
esttab w* using regression_output/presentation/w.rtf, replace



sort year
by year: egen fig_prop=mean(fem_in_gen) if marker==1
by year: egen fig=max(fig_prop)
drop fig_prop
label variable fig "Proportion of general elections featuring a female candidate"
preserve
forval i = 1977(1)2009{
capture drop _4yr`i'
capture drop maprop`i'
gen _4yr`i'=0
replace _4yr`i'=1 if year==`i' | year==`i'-1 | year==`i'-2 | year==`i'-3
egen maprop`i'=mean(fem_in_gen) if marker==1 & _4yr`i'==1
capture gen maprop=.
replace maprop=maprop`i' if marker==1 & year==`i'
}
label variable maprop "4 year moving average of the proportion of general elections featuring a female candidate"
scatter maprop year if marker==1

*****************
keep if mvm==1
*****************
/*Generate male challenger dummy*/
tab challenger
capture drop mcv
gen mcv=reweight if challenger==1
label variable mcv "Male challenger vote share, in mvm elections"
sort year state
by year state: gen topline=1 if _n==1
replace mcv=reweight if challenger==0 & open==1 & topline==1

reg mcv open t tsq 
est store z1
areg mcv open t tsq, absorb(state)
est store z2
esttab z* using regression_output/presentation/z.rtf, replace
restore



*****************
keep if mvf==1
*****************
/*Generate female vote variable and female spend variable*/
gen fv=female*reweight
replace fv=. if fv==0
sort year state
by year state: egen fvote=max(fv)
by year state: gen topline=1 if _n==1
drop fv
gen fls=female*lntotal
replace fls=. if fls==0
sort year state
by year state: egen flns=max(fls)
gen fs=female*_total
replace fs=. if fs==0
sort year state
by year state: egen fsp=max(fs)
drop fs
drop fls
label variable fvote "Reweighted female vote share in a 2 person (mvf) election"
label variable flns "Log of female spending in a 2 person (mvf) election"


/*Generate male vote variable*/
gen mv=.
replace mv=reweight if female==0
replace mv=. if mv==0
sort year state
by year state: egen mvote=max(mv)
drop mv
label variable mvote "Reweighted male vote share in a 2 person (mvf) election"


/*Generate male spend variable*/
gen mls=.
replace mls=lntotal if female==0
replace mls=. if mls==0
sort year state
by year state: egen mlns=max(mls)
drop mls
gen ms=_total if female==0
sort year state
by year state: egen msp=max(ms)
drop ms
drop if topline !=1
label variable mlns "Log of male spending in a 2 person (mvf) election"


/*Generate spend share variable*/
gen fspshr=.
replace fspshr=fsp/(msp+fsp)
gen mspshr=.
replace mspshr=1-fspshr
drop fsp msp
label variable fspshr "Share of female spending, out of all campaign spending for a general election"
label variable mspshr "Share of male spending, out of all campaign spending for a general election"

/*Generate spending data dummy*/
sort year state
by year state: egen spend=max(_total)
replace spend=1 if spend>0 & spend !=.
replace spend=0 if spend==.
list  year state spend, clean


***
*6*
***

reg fvote flns 
est store f1
areg fvote flns, absorb(state)
est store f2
reg fvote flns mlns
est store f3
areg fvote flns mlns, absorb(state)
est store f4
reg fvote fspshr
est store f5
areg fvote fspshr, absorb(state)
est store f6
esttab f* using regression_output/presentation/f.rtf, replace

reg fvote flns mlns minc finc
est store g1
areg fvote flns mlns minc finc, absorb(state)
test minc=-finc
est store g2
reg fvote flns mlns minc finc t 
est store g3
areg fvote flns mlns minc finc t, absorb(state)
est store g4
reg fvote fspshr minc finc t
est store g5
areg fvote fspshr minc finc t, absorb(state)
est store g6
esttab g* using regression_output/presentation/g.rtf, replace

gen flnsminc=flns*minc
gen flnsfinc=flns*finc
gen fspshrminc=fspshr*minc
gen fspshrfinc=fspshr*finc
areg fvote flns mlns minc finc flnsminc flnsfinc, absorb(state)
est store y1
areg fvote flns mlns minc finc t flnsminc flnsfinc, absorb(state)
est store y2
areg fvote fspshr minc finc fspshrminc fspshrfinc, absorb(state)
est store y3
areg fvote fspshr minc finc t fspshrminc fspshrfinc, absorb(state)
est store y4
esttab y* using regression_output/presentation/y.rtf, replace

***
*7*
***

reg mvote mlns minc finc t
est store h1
areg mvote mlns minc finc t, absorb(state)
est store h2
esttab h* using regression_output/presentation/h.rtf, replace

***
*8*
***

reg fvote t 
est store i1
predict resid1, resid
areg fvote t, absorb(state)
est store i2
predict resid2, resid
areg fvote t gfd, absorb(state)
est store i3
reg fvote t tsq 
est store i4
areg fvote t tsq, absorb(state)
est store i5
areg fvote t tsq gfd, absorb(state)
est store i6
esttab i* using regression_output/presentation/i.rtf, replace
scatter fvote year

scatter resid1 year, yline(0)
scatter resid2 year, yline(0)

***
*9*
***

gen pubfncminc=pubfnc*minc
gen pubfncfinc=pubfnc*finc
gen pubfncgfd=pubfnc*gfd


reg fvote pubfnc 
est store j1
reg fvote pubfnc gfd pubfncgfd
est store j2
reg fvote pubfnc if pfswitch==1
est store j3
reg fvote pubfnc td* sd* 
est store j4
reg fvote pubfnc minc finc pubfncminc pubfncfinc
est store j5
reg fvote pubfnc minc finc pubfncminc pubfncfinc if pfswitch==1
est store j6
reg fvote pubfnc minc finc pubfncminc pubfncfinc td* sd* 
est store j7
reg fvote partial full
est store j
reg fvote partial full if pfswitch==1
est store j9
esttab j* using regression_output/presentation/j.rtf, replace


****
*10*
****
gen opengfd=open*gfd

reg fvote open
est store k1
areg fvote open, absorb(state)
est store k2
areg fvote open gfd opengfd, absorb(state)
est store k3
reg fvote open t tsq
est store k4
areg fvote open t tsq, absorb(state)
est store k5
areg fvote open t tsq gfd opengfd, absorb(state)
est store k6
reg fvote open t tsq minc
est store k7
areg fvote open t tsq minc, absorb(state)
est store k8
areg fvote open t tsq minc gfd opengfd, absorb(state)
est store k9

esttab k* using regression_output/presentation/k.rtf, replace

log close
view results.smcl

